﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Threading.Tasks;

namespace FlexGridDataValidation.Models
{
    public class Stocks
    {
        [Required(AllowEmptyStrings =false,ErrorMessage ="{0} cannot be empty!")]
        public string StockID { get; set; }
        [Required(AllowEmptyStrings = false, ErrorMessage = "{0} cannot be empty!")]
        public string Description { get; set; }
        [Required(AllowEmptyStrings = false, ErrorMessage = "{0} cannot be empty!"),  StringLength(11, ErrorMessage = "The value should be length of 11!")]
        [RegularExpression("LOT-GCF-[0-9]{3}",ErrorMessage = "It should start with “LOT - GCF -” and last 3 character should be digits!")]
        public string LotNo { get; set; }
        [Required]
        [Range(10,1000,ErrorMessage = "The {0} should be between 10 and 1000!")]
        public double Price { get; set; }
        [Required]
        [Range(0, 0.20,ErrorMessage = "The {0} should be between 0 and 20%")]
        public double Discount { get; set; }
        [Required]
        [Range(0, int.MaxValue, ErrorMessage = "Please enter a positive number!")]
        public int Quantity { get; set; }
        
        public bool InStock { get; set; }

        public static IEnumerable<Stocks> GetStocks(int count)
        {
            List<Stocks> stocks = new List<Stocks>();
            var _stockPref = "GCF-";
            var _lotPref = "LOT-GCF-";
            var _furnitures = "Tables,Chair,Rounded Table,Sofa,Wood Chairs,Plastic Chairs,Laptop Table".Split(',');
            var _rnd = new Random();
            for (int i = 0; i < count; i++)
            {
                stocks.Add(new Stocks()
                {
                    Description=_furnitures[i%_furnitures.Length],
                    Discount= Stocks._getDiscount(_rnd.NextDouble()),
                    Quantity = _rnd.Next(1,20),
                    InStock= (i==3) ? false : true,
                    LotNo = _lotPref+(i % _furnitures.Length).ToString("D3"),
                    Price = _rnd.NextDouble()*1000,
                    StockID = _stockPref+ i.ToString("D4")
                });
            }
            return stocks;
        }
        private static double _getDiscount(double discount)
        {
            if(discount>0 && discount < 0.21 )
            {
                return discount;
            }
            return _getDiscount(discount - 0.20);
        }

    }
}
